Learn R Programming

asypow (version 2012.04-1)

asypow.noncent: Asymptotic Noncentrality Parameter

Description

Given an information matrix, alternative hypothesis parameter values, and constraints that create the null hypothesis from the alternative, calculates noncentrality parameter, degrees of freedom and parameter value estimates under the null hypothesis.

Usage

asypow.noncent(theta.ha, info.mat, constraints, 
               nobs.ell=1, get.ho=TRUE)

Arguments

theta.ha
Array of parameter values under the alternative hypothesis.
info.mat
The information matrix, the second derivate matrix of the expected log likelihood under the alternative hypothesis. The negative of the hessian matrix.
constraints
The constraints which set the null hypothesis from the alternative hypothesis. They are in matrix form. CONSTRAINT[,1] is 1 for setting parameter to a value 2 for equality of two parameters CONSTRAINT[,2] is case on CONSTRAIN
nobs.ell
The number of observations used in computing the information matrix. That is, info.mat is that for nobs.ell observations. Default is 1, which is the correct value for all of the 'info.' routines supplied here.
get.ho
If TRUE, estimates of the parameter values under the null hypothesis are calculated and returned, otherwise not. Default is TRUE.

Value

  • Returns a list including
  • wThe noncentrality parameter for 1 observation.
  • dfThe degrees of freedom of the test
  • theta.hoEstimates of the parameter values under the null hypothesis.

concept

noncentrality

References

Cox, D.R. and Hinkley, D.V. (1974). Theoretical Statistics Chapman and Hall, London.

See Also

asypow.n, asypow.sig, asypow.power

Examples

Run this code
# Three Sample Poisson Example :
#    Three independent Poisson processes produce events at
#    mean rates of 1, 2 and 3 per day. 
# Find the information matrix
pois.mean <- c(1,2,3)
info.pois <- info.poisson.kgroup(pois.mean,group.size=3)
# Create the constraints matrix
constraints <- matrix(c(2,1,2,2,2,3),ncol=3,byrow=TRUE)
# Calculate noncentrality parameter, degrees of freedom and parameter
# value estimates under the null hypothesis for the test.
poisson.object <- asypow.noncent(pois.mean,info.pois,constraints)

Run the code above in your browser using DataLab