info.binomial.kgroup: Expected Information Matrix for Single or Multiple Group Binomial
Description
Calculates expected information matrix for a single observation
for single or multiple group binomial distribution.
The natural null hypothesis for a single group is that that the probability
is some specified value. For multiple groups, the natural null hypothesis
is that the group probabilities are the same.
Usage
info.binomial.kgroup(p, group.size=1)
Arguments
p
Scalar or vector of probability values. The i'th component is the
(alternative hypothesis or true) probability of an event in the i'th
group.
group.size
Needed only if there are several groups with unequal sample
sizes. The value of the i'th component is the relative sample size of
the i'th group. The calculation made is for a single observation
spread over the several groups in proportion t
Value
Expected information matrix for a single observation. The matrix is
square with each dimension the number of groups.
concept
information
References
Cox, D.R. and Hinkley, D.V. (1974).
Theoretical Statistics
Chapman and Hall, London.
# Find the information matrix for a 2 sample binomial with# probability of events .2 and .4 and sample sizes 10 and 11info.binom <- info.binomial.kgroup(c(.2,.4), c(10,11))
print(info.binom)