Learn R Programming

asypow (version 2015.6.25)

info.ordinal.kgroup: Expected Information Matrix for Single or Multiple Group Ordinal Observations

Description

Calculates expected information matrix for a single observation for ordered outcomes in a single or multiple groups.

The natural null hypothesis for a single group is that the probabilities of the outcomes is some specified set of values. For multiple groups, the natural null hypothesis is that the probabilities are the same.

Usage

info.ordinal.kgroup(p, group.size=1)

Arguments

p
If there are $n$ ordered outcome categories and $k$ groups then $p$ will have dimension $k \times (n-1)$. If the number of groups is one, then $p$ can be a vector of length (n-1).

Within a single group, $p_i$ is the probability tha

group.size
Needed only if there are to be several groups with unequal sample sizes. The value of the i'th component is the relative sample size of the i'th group. The calculation made is for a single observation spread over the several groups in propor

Value

  • Expected information matrix for a single observation. The matrix is dimensioned $(k(n-1))\times (k(n-1))$ {( k*(n-1) ) X ( k*(n-1) )}.

concept

information

References

Cox, D.R. and Hinkley, D.V. (1974). Theoretical Statistics Chapman and Hall, London.

See Also

info.binomial.kgroup, info.poisson.kgroup, info.expsurv.kgroup

Examples

Run this code
# Find the information matrix for a 2 group ordinal
# model with 4 categories.
p1 <- c(.1, .2, .3)  # Probabilities for group 1
p2 <- c(.2, .5, .7)  # Probabilities for group 2
p <- rbind(p1,p2)
ngrps <- c(.4, .6)  # Percentage of data in each group
info.ord <- info.ordinal.kgroup(p, ngrps)
print(info.ord)

Run the code above in your browser using DataLab