Learn R Programming

asypow (version 2012.04-1)

info.poisson.kgroup: Expected Information Matrix for Single or Multiple Group Poisson

Description

Calculates expected information matrix for a single observation for single or multiple group Poisson distribution.

The natural null hypothesis for a single group is that that the mean is some specified value. For multiple groups, the natural null hypothesis is that the group means are the same.

Usage

info.poisson.kgroup(lambda, group.size=1)

Arguments

lambda
Scalar or vector of Poisson means for the groups. The i'th component is the (alternative hypothesis or true) mean of the i'th group.
group.size
Needed only if there are to be several groups with unequal sample sizes. The value of the i'th component is the relative sample size of the i'th group. The calculation made is for a single observation spread over the several groups in proportio

Value

  • Expected information matrix for a single observation. The matrix is square with dimension equal to the number of groups.

concept

information

References

Cox, D.R. and Hinkley, D.V. (1974). Theoretical Statistics Chapman and Hall, London.

See Also

info.binomial.kgroup, info.ordinal.kgroup, info.expsurv.kgroup

Examples

Run this code
# Find the information matrix for a 3 sample Poisson with
# means 1, 2 and 3 and equal sample sizes
info.pois <- info.poisson.kgroup(c(1,2,3))
print(info.pois)

Run the code above in your browser using DataLab