The clinical trial will accrue subjects over a time period $L$. Each subject will enter the study at a random time between 0 and $L$, so the subject's follow up time, $U$, will be uniformly distributed between 0 and $L$. A subject with follow up time $U$, can die at a time $t$ between 0 and $U$, or the subject can be withdrawn alive at time $U$. The density of time to death is exponential distribution with hazard, $w$.
The parameter $w$ depends on a covariate, $x$, via the exponentiation of a linear or quadratic function of $x$, $w = exp(a + b*x)$ or $w = exp(a + b*x + c*x^2)$.
This model is both the proportional hazards model and the accelerated failure model for exponential survival.
info.expsurv.design(model="linear", theta, L, xpoints, natx=1, group.size=1)info.binomial.design,
info.poisson.design,
info.ordinal.design
# Find the information matrix for a clinical trial
# with hazard w(x) = -0.848 + 0.7*x which lasts
# three years and has 10 x values equally spaced
# between -3 and 3 with equal sample sizes.
ab <- c(-.848, .7)
covar <- seq(-3, 3, length=10)
LL <- 3
info.expsurv <- info.expsurv.design(theta = ab, L = LL, xpoints = covar)
print(info.expsurv)
Run the code above in your browser using DataLab