info.expsurv.kgroup: Expected Information Matrix for a Single or Multiple Group
Clinical Trial with Exponential Survival
Description
Calculates expected information matrix for a single observation
for a single or multiple group clinical trial with exponential
survival.
The clinical trial will accrue subjects over a time period $L$.
Each subject will enter the study at a random time between 0
and $L$, so the subject's follow up time, $U$, will be uniformly
distributed between 0 and $L$. A subject with follow up
time $U$, can die at a time $t$ between 0 and $U$,
or the subject can
be withdrawn alive at time $U$. The density of time to death
is exponential distribution with hazard, $w$.
Usage
info.expsurv.kgroup(w, L, group.size=1)
Arguments
w
Scalar or vector of exponential rates (reciprocals of the mean
survival time ) for the groups. The i'th component is the (alternative
hypothesis or true) rate of the i'th group.
L
The length of the clinical trial. If all groups have the same
trial length, L should be a single number; otherwise, L should
be a vector the same length as w where L[i] is the length
of the clinical trial for the i'th group.
group.size
Needed only if there are to be several groups with unequal sample
sizes. The value of the i'th component is the relative sample size of
the i'th group. The calculation made is for a single observation
spread over the several groups in propor
Value
Expected information matrix for a single observation. The matrix is
square with dimension equal to the number of groups.
concept
information
References
Cox, D.R. and Hinkley, D.V. (1974).
Theoretical Statistics
Chapman and Hall, London.