The clinical trial will accrue subjects over a time period $L$. Each subject will enter the study at a random time between 0 and $L$, so the subject's follow up time, $U$, will be uniformly distributed between 0 and $L$. A subject with follow up time $U$, can die at a time $t$ between 0 and $U$, or the subject can be withdrawn alive at time $U$. The density of time to death is exponential distribution with hazard, $w$.
info.expsurv.kgroup(w, L, group.size=1)info.binomial.kgroup,
info.poisson.kgroup,
info.ordinal.kgroup
# Find the information matrix for a clinical trial of
# length 3 with hazard 1
info.expsurv <- info.expsurv.kgroup(1, 3)
print(info.expsurv)
Run the code above in your browser using DataLab